abacusai.model_training_type_for_deployment — AbacusAI documentation

# abacusai.model_training_type_for_deployment

## Classes

`ModelTrainingTypeForDeployment` | Model training types for deployment.

## Module Contents

class abacusai.model_training_type_for_deployment.ModelTrainingTypeForDeployment(client, label=None, value=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Model training types for deployment.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - label (str) – Labels to show to users in deployment UI

    - value (str) – Value to use on backend for deployment API call

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict